#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-

# License: GNU General Public License v2

from cmk.graphing.v1 import metrics, Title
from cmk.graphing.v1.graphs import Graph

# Metrics for DHOST ThreadPool
metric_threadmaxwaittime = metrics.Metric(
    name="ThreadMaxWaitTime",
    title=Title("DHOST Thread Maximum Wait Time"),
    unit=metrics.Unit(metrics.TimeNotation()),
    color=metrics.Color.BROWN,
)

# Metric for DClient
metric_maxoutboundconnection = metrics.Metric(
    name="MaxOutBoundConnection",
    title=Title("DClient Maximum outbound connection count"),
    unit=metrics.Unit(metrics.SINotation("count")),
    color=metrics.Color.BROWN,
)

# Metrics for LDAP traffic
metric_inbytes = metrics.Metric(
    name="inBytes",
    title=Title("LDAP traffic bytes in"),
    unit=metrics.Unit(metrics.SINotation("bytes")),
    color=metrics.Color.BROWN,
)

metric_outbytes = metrics.Metric(
    name="outBytes",
    title=Title("LDAP traffic bytes Out"),
    unit=metrics.Unit(metrics.SINotation("bytes")),
    color=metrics.Color.BLUE,
)

# Combined graph of both inBytes and outBytes for LDAP Traffic
graph_ldaptraffic_combined = Graph(
    name = "ldap_traffic",
    title = Title("Services in OK state out of total"),
    simple_lines=[ "outBytes", "inBytes" ],
    
)

# Metric for Partition Agent
metric_maxringdelta = metrics.Metric(
    name="MaxRingDelta",
    title=Title("Maximum amount of data not synchronized between any two servers in the replica ring"),
    unit=metrics.Unit(metrics.TimeNotation()),
    color=metrics.Color.BROWN,
)